package ch.sahits.datastructure;

import java.util.Map;

/**
 * This data structure holds a key value pair.
 * The key is a string the value can be an abitrairy
 * data type.
 * The Pair is used as a list element where each key may
 * only occure once.
 * @author Andi Hotz
 *
 */
public class Pair implements Map.Entry<String,Object>{

	private String key;
	private Object value;
	/**
	 * Constructor initializes the key value pair
	 * @param key
	 * @param value
	 */
	public Pair(String key, Object value) {
		super();
		this.key = key;
		this.value = value;
	}
	/**
	 * Retrieve the key
	 * @return key value
	 */
	public String getKey() {
		return key;
	}
	/**
	 * Retrieve the value
	 * @return value
	 */
	public Object getValue() {
		return value;
	}
	/**
	 * {@inheritDoc}
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((key == null) ? 0 : key.hashCode());
		return result;
	}
	/**
	 * Since a Pair is always part of a list where a key
	 * may only occure once the equals method does only
	 * check for the equality of the key.
	 * @param obj Objekt to be compared
	 * @return true if the key is equal
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Pair other = (Pair) obj;
		if (key == null) {
			if (other.key != null)
				return false;
		} else if (!key.equals(other.key))
			return false;
		return true;
	}
	/**
	 * Doe nothing. Initialize the value at constructor time
	 * @param value null
	 * @return RuntimeException
	 * 
	 */
	public Object setValue(Object value) {
		throw new RuntimeException("This Enty is initialized at constructor time");
	}
	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return "Pair\n [" + (key != null ? "key=" + key + "\n " : "")
				+ (value != null ? "value=" + value : "") + "]";
	}
	
	
}
