package ch.sahits.math;
/**
 * This class implements the standard normal distribution:<br>
 * <img src="http://upload.wikimedia.org/math/7/6/f/76f2a2c45e5619aef2717d523ff7f037.png"><br>
 * <img src=http://upload.wikimedia.org/wikipedia/commons/thumb/1/1b/Normal_distribution_pdf.png/325px-Normal_distribution_pdf.png">
 * 
 * @author Andi Hotz (c) by Sahits.ch 2007
 * @version 1.0
 */
public class StandardNormalDistribution implements IFunction {
	
	private double mean=0;
	private double diviation=1;
	/**
	 * Default constructor for the default standard normal distribution with mean=0.0
	 * and diviation=1.0
	 */
	public StandardNormalDistribution(){
		super();
	}
	/**
	 * Constructor that initializes a different mean and diviation
	 * @param m mean
	 * @param d diviation
	 */
	public StandardNormalDistribution(double m,double d){
		mean=m;
		diviation=d;
	}
	/**
	 * Implement the function<br>
	 * <img src="http://upload.wikimedia.org/math/7/6/f/76f2a2c45e5619aef2717d523ff7f037.png"><br>
	 * @see ch.sahits.civ.util.IFunction#f(double)
	 */
	public double f(double x) {
		double a = 1.0/(diviation*Math.sqrt(2*Math.PI));
		double exponent = -1/2*(x-mean)*(x-mean)/(diviation*diviation);
		return a*Math.exp(exponent);
	}

}
