package ch.sahits.test;
/**
 * This class represents the result of a complex comparison.
 * Besides the simple true/false value there is also a textual
 * message explaning how the comarison is unequal
 * @author Andi Hotz, Sahits GmbH
 * @since 2.1.0
 *
 */
public class ComparetorResult {
	/** Instance representing a successfull comparison */
	public static ComparetorResult TRUE = new ComparetorResult(true, null);
	/** result value */
	private boolean result;
	/** Message of the result */
	private String message=null;
	
	public ComparetorResult(boolean resultValue,String msg){
		if (!resultValue){
			if (msg==null){
				throw new IllegalArgumentException("The message must be specified");
			}
		}
		result=resultValue;
		message=msg;
	}
	/**
	 * Check if the comparison was successful
	 * @return true if the comparison was successful
	 */
	public boolean isTrue() {
		return result;
	}
	/**
	 * Retrieve the comparison message
	 * @return message of the error or null if the comparison was successful
	 */
	public String getMessage() {
		return message;
	}
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((message == null) ? 0 : message.hashCode());
		result = prime * result + (this.result ? 1231 : 1237);
		return result;
	}
	/**
	 * Instance of this class is equal if the test and the message are equal
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		ComparetorResult other = (ComparetorResult) obj;
		if (message == null) {
			if (other.message != null)
				return false;
		} else if (!message.equals(other.message))
			return false;
		if (result != other.result)
			return false;
		return true;
	}
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("ComparetorResult [message=");
		builder.append(message);
		builder.append(", result=");
		builder.append(result);
		builder.append("]");
		return builder.toString();
	}

}
